from client import Sparq

client = Sparq("your-api-key-here")

# edit accordingly
plan = client.plan(
    major= "Computer Science",
    cc_courses= [
        # EVC Courses (based on actual transcript)
        {"code": "COMSC 075", "title": "Computer Science I", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "COMSC 076", "title": "Computer Science II", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "COMS 020", "title": "Oral Communication", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "ART 096", "title": "History of Asian Art", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "COMS 035", "title": "Intercultural Communication", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "PSYCH 001", "title": "General Psychology", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "PHIL 060", "title": "Logic and Critical Thinking", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "PHIL 010", "title": "Introduction to Philosophy", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "PHIL 065", "title": "Introduction to Ethics", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "COMSC 080", "title": "Discrete Structures", "grade": "A", "institution": "Evergreen Valley College"},
        {"code": "HIST 017A", "title": "History of the United States", "grade": "A", "institution": "Evergreen Valley College"},
        # SJCC Courses
        {"code": "ENGL 001A", "title": "English Composition", "grade": "A", "institution": "San Jose City College"},
    ],
    ap_exams= [
        {"test": "Calculus AB", "score": 5},
        {"test": "Calculus BC", "score": 4},
        {"test": "World History", "score": 4},
        {"test": "Physics C, Mechanics", "score": 4},
    ],
    sjsu_courses= [
        {"code": "MATH 32", "title": "Calculus III", "status": "In Progress", "term": "Fall 2025"},
        {"code": "CS 49J", "title": "Programming in Java", "status": "In Progress", "term": "Fall 2025"},
        {"code": "NUFS 16", "title": "Nutrition", "status": "In Progress", "term": "Fall 2025"},
        {"code": "METR 10", "title": "Weather and Climate", "status": "In Progress", "term": "Fall 2025"},
    ],
    units_per_semester= 15
)

print(plan)


#!/usr/bin/env python3

import requests
import os
from pathlib import Path

API_URL = "https://sparq-api.onrender.com"

def save_api_key(api_key, email):
    config_dir = Path.home() / ".sparq"
    config_dir.mkdir(exist_ok=True)
    config_file = config_dir / "config.txt"
    
    with open(config_file, "w") as f:
        f.write(f"API_KEY={api_key}\n")
        f.write(f"EMAIL={email}\n")
    
    print(f"\nAPI key saved to {config_file}")

def register():
    email = input("Email: ").strip()
    
    if not email or "@" not in email:
        print("Invalid email address")
        return
    
    response = requests.post(
        f"{API_URL}/register",
        json={"email": email},
        headers={"Content-Type": "application/json"}
    )
    
    if response.status_code == 200:
        data = response.json()
        if data.get("status") == "pending_verification":
            print("Code already sent. Check your email.")
        else:
            print("Verification code sent to your email")
    elif response.status_code != 200:
        print(response.json()['detail'])
        return
    
    code = input("Enter code: ").strip()
    
    response = requests.post(
        f"{API_URL}/verify",
        json={"email": email, "code": code},
        headers={"Content-Type": "application/json"}
    )
    
    if response.status_code == 200:
        api_key = response.json()["api_key"]
        print(f"\nAPI Key: {api_key}")
        save_api_key(api_key, email)
    else:
        print(response.json()['detail'])

if __name__ == "__main__":
    register()

